@@ -13,7 +13,7 @@ from status_code import StatusCode
 class RequestHandler(object):
 
     def connect(self, url):
-        if not url.startswith("file:"):
+        if not (url.startswith("file:") or url.startswith("about:")):
             self.request_url = url
             self._create_connection()
             self._store_response()
